#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// Pivot and Medium alert
    /// </summary>
    [Description("Pivot and Medium alert")]
    public class gmPivMedAlert2 : Indicator
    {
        #region Variables
        // Wizard generated variables
            private string up_alert = @"alert1.wav"; // Default setting for Up_alert
            private string down_alert = @"alert2.wav"; // Default setting for Down_alert
            private string pivot_alert = @"alert3.wav"; // Default setting for Pivot_alert
            private bool pivot_alert_allow = true; // Default setting for Pivot_alert_allow
		    private bool medium_alert_allow = true; // Default setting for Medium_alert_allow

        // User defined variables (add any user defined variables below)
		
			private double medium_up = 0;
			private double medium_down = 0;
			private	double support_s = 0;
			private double resist_s = 0;
			private	double support_s_old = 0;
			private double resist_s_old = 0;
		
		
        #endregion

        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {
            Overlay				= true;
			CalculateOnBarClose = true;
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
			if (CurrentBar < 20)
        		return;
			
			if(pivot_alert_allow)
			{
				support_s = KPPivot2Color(0).SupportShown[0];
				resist_s = KPPivot2Color(0).ResistanceShown[0];
				
				if((support_s != support_s_old) || (resist_s != resist_s_old))
				{	PlaySound(pivot_alert);  }
			}
			
			
			if(medium_alert_allow)
			{
				if(KPMedium().SignalUp.ContainsValue(0))
				{PlaySound(up_alert);}

				if(KPMedium().SignalDn.ContainsValue(0))
				{PlaySound(down_alert);}
			}
			
				support_s_old = support_s;
				resist_s_old = resist_s;
			
        }

        #region Properties

        [Description("sound for medium up")]
        [GridCategory("Parameters")]
        public string Up_alert
        {
            get { return up_alert; }
            set { up_alert = value; }
        }

        [Description("sound for medium down")]
        [GridCategory("Parameters")]
        public string Down_alert
        {
            get { return down_alert; }
            set { down_alert = value; }
        }

        [Description("sound for a new pivot")]
        [GridCategory("Parameters")]
        public string Pivot_alert
        {
            get { return pivot_alert; }
            set { pivot_alert = value; }
        }

        [Description("pivot alert active")]
        [GridCategory("Parameters")]
        public bool Pivot_alert_allow
        {
            get { return pivot_alert_allow; }
            set { pivot_alert_allow = value; }
        }
		
		[Description("medium alert active")]
        [GridCategory("Parameters")]
        public bool Medium_alert_allow
        {
            get { return medium_alert_allow; }
            set { medium_alert_allow = value; }
        }

		
		
        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private gmPivMedAlert2[] cachegmPivMedAlert2 = null;

        private static gmPivMedAlert2 checkgmPivMedAlert2 = new gmPivMedAlert2();

        /// <summary>
        /// Pivot and Medium alert
        /// </summary>
        /// <returns></returns>
        public gmPivMedAlert2 gmPivMedAlert2(string down_alert, bool medium_alert_allow, string pivot_alert, bool pivot_alert_allow, string up_alert)
        {
            return gmPivMedAlert2(Input, down_alert, medium_alert_allow, pivot_alert, pivot_alert_allow, up_alert);
        }

        /// <summary>
        /// Pivot and Medium alert
        /// </summary>
        /// <returns></returns>
        public gmPivMedAlert2 gmPivMedAlert2(Data.IDataSeries input, string down_alert, bool medium_alert_allow, string pivot_alert, bool pivot_alert_allow, string up_alert)
        {
            if (cachegmPivMedAlert2 != null)
                for (int idx = 0; idx < cachegmPivMedAlert2.Length; idx++)
                    if (cachegmPivMedAlert2[idx].Down_alert == down_alert && cachegmPivMedAlert2[idx].Medium_alert_allow == medium_alert_allow && cachegmPivMedAlert2[idx].Pivot_alert == pivot_alert && cachegmPivMedAlert2[idx].Pivot_alert_allow == pivot_alert_allow && cachegmPivMedAlert2[idx].Up_alert == up_alert && cachegmPivMedAlert2[idx].EqualsInput(input))
                        return cachegmPivMedAlert2[idx];

            lock (checkgmPivMedAlert2)
            {
                checkgmPivMedAlert2.Down_alert = down_alert;
                down_alert = checkgmPivMedAlert2.Down_alert;
                checkgmPivMedAlert2.Medium_alert_allow = medium_alert_allow;
                medium_alert_allow = checkgmPivMedAlert2.Medium_alert_allow;
                checkgmPivMedAlert2.Pivot_alert = pivot_alert;
                pivot_alert = checkgmPivMedAlert2.Pivot_alert;
                checkgmPivMedAlert2.Pivot_alert_allow = pivot_alert_allow;
                pivot_alert_allow = checkgmPivMedAlert2.Pivot_alert_allow;
                checkgmPivMedAlert2.Up_alert = up_alert;
                up_alert = checkgmPivMedAlert2.Up_alert;

                if (cachegmPivMedAlert2 != null)
                    for (int idx = 0; idx < cachegmPivMedAlert2.Length; idx++)
                        if (cachegmPivMedAlert2[idx].Down_alert == down_alert && cachegmPivMedAlert2[idx].Medium_alert_allow == medium_alert_allow && cachegmPivMedAlert2[idx].Pivot_alert == pivot_alert && cachegmPivMedAlert2[idx].Pivot_alert_allow == pivot_alert_allow && cachegmPivMedAlert2[idx].Up_alert == up_alert && cachegmPivMedAlert2[idx].EqualsInput(input))
                            return cachegmPivMedAlert2[idx];

                gmPivMedAlert2 indicator = new gmPivMedAlert2();
                indicator.BarsRequired = BarsRequired;
                indicator.CalculateOnBarClose = CalculateOnBarClose;
#if NT7
                indicator.ForceMaximumBarsLookBack256 = ForceMaximumBarsLookBack256;
                indicator.MaximumBarsLookBack = MaximumBarsLookBack;
#endif
                indicator.Input = input;
                indicator.Down_alert = down_alert;
                indicator.Medium_alert_allow = medium_alert_allow;
                indicator.Pivot_alert = pivot_alert;
                indicator.Pivot_alert_allow = pivot_alert_allow;
                indicator.Up_alert = up_alert;
                Indicators.Add(indicator);
                indicator.SetUp();

                gmPivMedAlert2[] tmp = new gmPivMedAlert2[cachegmPivMedAlert2 == null ? 1 : cachegmPivMedAlert2.Length + 1];
                if (cachegmPivMedAlert2 != null)
                    cachegmPivMedAlert2.CopyTo(tmp, 0);
                tmp[tmp.Length - 1] = indicator;
                cachegmPivMedAlert2 = tmp;
                return indicator;
            }
        }
    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// Pivot and Medium alert
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.gmPivMedAlert2 gmPivMedAlert2(string down_alert, bool medium_alert_allow, string pivot_alert, bool pivot_alert_allow, string up_alert)
        {
            return _indicator.gmPivMedAlert2(Input, down_alert, medium_alert_allow, pivot_alert, pivot_alert_allow, up_alert);
        }

        /// <summary>
        /// Pivot and Medium alert
        /// </summary>
        /// <returns></returns>
        public Indicator.gmPivMedAlert2 gmPivMedAlert2(Data.IDataSeries input, string down_alert, bool medium_alert_allow, string pivot_alert, bool pivot_alert_allow, string up_alert)
        {
            return _indicator.gmPivMedAlert2(input, down_alert, medium_alert_allow, pivot_alert, pivot_alert_allow, up_alert);
        }
    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// Pivot and Medium alert
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.gmPivMedAlert2 gmPivMedAlert2(string down_alert, bool medium_alert_allow, string pivot_alert, bool pivot_alert_allow, string up_alert)
        {
            return _indicator.gmPivMedAlert2(Input, down_alert, medium_alert_allow, pivot_alert, pivot_alert_allow, up_alert);
        }

        /// <summary>
        /// Pivot and Medium alert
        /// </summary>
        /// <returns></returns>
        public Indicator.gmPivMedAlert2 gmPivMedAlert2(Data.IDataSeries input, string down_alert, bool medium_alert_allow, string pivot_alert, bool pivot_alert_allow, string up_alert)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.gmPivMedAlert2(input, down_alert, medium_alert_allow, pivot_alert, pivot_alert_allow, up_alert);
        }
    }
}
#endregion
